@@ -1280,7 +1280,7 @@ class RadioButtonGroup:
       index = 0
     for i in range(length):
       shortcut = self.shortcuts[index]
-      if shortcut and wx.GetKeyState(ord(shortcut)):
+      if shortcut and application.QuiskGetKeyState(ord(shortcut)):
         break
       index += 1
       if index >= length:
